===============================
rui (叡)
===============================

.. image:: https://badge.fury.io/py/rui.png
    :target: http://badge.fury.io/py/rui
    
.. image:: https://travis-ci.org/timothyhahn/rui.png?branch=master
        :target: https://travis-ci.org/timothyhahn/rui

.. image:: https://pypip.in/d/rui/badge.png
        :target: https://crate.io/packages/rui?version=latest


An imperfect Python ECS

* Documentation: http://rui.rtfd.org.
* Github: http://github.com/timothyhahn/rui
* Free software: BSD license
* PyPI: https://pypi.python.org/pypi/rui/


Features
--------

* A simple Python Entity Component System
* Unoptimized
* Favors World based access, eschews Managers (Artemis, which inspired this, uses both)
* To learn more about Entity Component Systems
    * http://www.gamedev.net/page/resources/_/technical/game-programming/understanding-component-entity-systems-r3013
    * http://www.randygaul.net/2013/05/20/component-based-engine-design/
    * http://gamadu.com/artemis/manual.html
